@@ -7,8 +7,9 @@ package Net::LDAP::Bind;
 use strict;
 use Net::LDAP qw(LDAP_SASL_BIND_IN_PROGRESS LDAP_DECODING_ERROR LDAP_SUCCESS);
 use Net::LDAP::Message;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
 
+$VERSION = "1.02";
 @ISA = qw(Net::LDAP::Message);
 
 sub _sasl_info {
