@@ -1,4 +1,4 @@
-# Copyright (c) 1997-2000 Graham Barr <gbarr@pobox.com>. All rights reserved.
+# Copyright (c) 1997-2003 Graham Barr <gbarr@pobox.com>. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
@@ -9,7 +9,7 @@ use Net::LDAP::ASN qw(LDAPEntry);
 use Net::LDAP::Constant qw(LDAP_LOCAL_ERROR);
 use vars qw($VERSION);
 
-$VERSION = "0.17";
+$VERSION = "0.21";
 
 sub new {
   my $self = shift;
@@ -20,6 +20,29 @@ sub new {
   $entry;
 }
 
+sub clone {
+  my $self  = shift;
+  my $clone = $self->new();
+
+  $clone->dn($self->dn());
+  foreach ($self->attributes()) {
+    $clone->add($_ => [$self->get_value($_)]);
+  }
+
+  $clone->{changetype} = $self->{changetype};
+  my @changes = @{$self->{changes}};
+  while (my($action, $cmd) = splice(@changes,0,2)) {
+    my @new_cmd;
+    my @cmd = @$cmd;
+    while (my($type, $val) = splice(@cmd,0,2)) {
+      push @new_cmd, $type, [ @$val ];
+    }
+    push @{$clone->{changes}}, $action, \@new_cmd;
+  }
+
+  $clone;
+}
+
 # Build attrs cache, created when needed
 
 sub _build_attrs {
@@ -227,7 +250,7 @@ sub update {
   }
   else {
     require Net::LDAP::Message;
-    $mesg = Net::LDAP::Message->new( {} );
+    $mesg = Net::LDAP::Message->new( $ldap );
     $mesg->set_error(LDAP_LOCAL_ERROR,"No attributes to update");
   }
 
@@ -242,7 +265,7 @@ sub dump {
 
   my $asn = $self->{asn};
   print "-" x 72,"\n";
-  print "dn:",$asn->{objectName},"\n\n";
+  print "dn:",$asn->{objectName},"\n\n" if $asn->{objectName};
 
   my($attr,$val);
   my $l = 0;
@@ -287,7 +310,8 @@ sub asn {
 }
 
 sub changes {
-  @{shift->{'changes'}}
+  my $ref = shift->{'changes'};
+  $ref ? @$ref : ();
 }
 
 1;
